// **** BEGIN LICENSE BLOCK ****
//   Copyright(c) 2009-2010 MATSUZAWA Jiro
//
//   This program is free software; you can redistribute it and/or modify
//   it under the terms of the GNU General Public License as published by
//   the Free Software Foundation; either version 2 of the License, or
//   (at your option) any later version.
//
//   This program is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU General Public License for more details.
//
//   You should have received a copy of the GNU General Public License
//   along with this program; if not, write to the Free Software
//   Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA
//   02110-1301, USA.  */
// **** END LICENSE BLOCK ****

var rencon;
if (!rencon) {
    rencon = {};
} else if (typeof rencon != "object") {
    throw new Error("");
}

rencon.System = function(){}

//////////////////////////////////////////
// public
//////////////////////////////////////////

////////////////////////////////
// constant
////////////////////////////////
rencon.System.LINUX    = 0;
rencon.System.UNIX     = 1;
rencon.System.MAC_OS   = 2;
rencon.System.WINDOWS  = 3;
rencon.System.OTHER_OS = -1;


////////////////////////////////
// method
////////////////////////////////
rencon.System.getEnv = function(
        key
        )
{
    if ( !(typeof key == "string") ) {
        return "";
    }

    if (!rencon.System._envServer) {
        rencon.System._envServer = Components.classes["@mozilla.org/process/environment;1"].
                            getService(Components.interfaces.nsIEnvironment);
    }

    return rencon.System._envServer.get(key);
}


rencon.System.encoding = function()
{
    var code = "UTF-8";
    switch (rencon.System.os()) {
    case rencon.System.WINDOWS :
    case rencon.System.MAC_OS  :
        code =  "Shift_JIS";
        break;

    case rencon.System.LINUX   :
    case rencon.System.UNIX    :
        var locale = rencon.System.getEnv("LANG").toLowerCase();
        if (locale.indexOf("utf") >= 0) {
            code = "UTF-8";
        } else if (locale.indexOf("euc") >= 0) {
            code = "EUC-JP";
        } else if (locale.indexOf("sjis") >= 0) {
            code = "Shift-JIS";
        }
        break;

    defalut :
        break;
    }

    return code;
}


rencon.System.os = function()
{
    if (!rencon.System._os) {
        rencon.System._os = rencon.System._getOs();
    }
    return rencon.System._os;
}


rencon.System.homeDir = function()
{
    if (!rencon.System._homeDir) {
        rencon.System._homeDir = rencon.System._getHomeDir();
    }
    return rencon.System._homeDir;
}


rencon.System.pathDelimiter = function()
{
    if (!rencon.System._pathDelimiter) {
        rencon.System._pathDelimiter = rencon.System._getPathDelimiter();
    }
    return rencon.System._pathDelimiter;
}


//////////////////////////////////////////
// private
//////////////////////////////////////////

rencon.System._getOs = function()
{
    const win   = "win32";
    const mac   = "mac";
    const linux = "linux";
    const unix  = "unix";
    var pf = navigator.platform.toLowerCase();
    // case Windows
    if (pf.indexOf(win) >= 0) {
        return rencon.System.WINDOWS;
    }
    // case Mac
    else if (pf.indexOf(mac) >= 0) {
        return rencon.System.MAC_OS;
    }
    // case Linux
    else if (pf.indexOf(linux) >= 0) {
        return rencon.System.LINUX;
    }
    // case UNIX
    else if (pf.indexOf(unix) >= 0) {
        return rencon.System.UNIX;
    }
    // the other
    else {
        return rencon.System.OTHER_OS;
    }

    // unexpected
    return rencon.System.OTHER_OS;
}

rencon.System._getHomeDir = function()
{
    var path = "";
    switch (rencon.System.os()) {
    case rencon.System.WINDOWS :
        path =  rencon.System.getEnv("USERPROFILE") ||
                rencon.System.getEnv("HOMEDRIVE") + rencon.System.getEnv("HOMEPATH");
        break;

    case rencon.System.MAC_OS  :
    case rencon.System.LINUX   :
    case rencon.System.UNIX    :
        path =  rencon.System.getEnv("HOME");
        break;

    defalut :
        break;
    }
    if (path == "") {
        throw new Error("get home directory NG");
    }

    return path;
}

rencon.System._getPathDelimiter = function()
{
    var d = "";
    switch (rencon.System.os()) {
    case rencon.System.WINDOWS :
        d =  "\\";
        break;

    case rencon.System.MAC_OS  :
    case rencon.System.LINUX   :
    case rencon.System.UNIX    :
        d =  "/";
        break;

    defalut :
        break;
    }

    if (d == "") {
        throw new Error("get path delimiter NG");
    }

    return d;
}
